package de.hftstuttgart.unifiedticketing.core;

import java.util.Date;
import java.util.logging.Formatter;
import java.util.logging.*;

public class Logging
{
    private static Handler handler;
    private static Logger mainLogger;
    private static Logger logger;

    static
    {
        mainLogger = Logger.getLogger("de.hftstuttgart.unifiedticketing");
        mainLogger.setUseParentHandlers(false);
        handler = new ConsoleHandler();
        handler.setFormatter(new SimpleFormatter() {
            final String format = "[%1$tFT%1$tT%1$tz] [%2$-7s] [%3$s.%4$s] %5$s%n";

            @Override
            public synchronized String format(LogRecord lr) {
                return String.format(format,
                    new Date(lr.getMillis()),
                    lr.getLevel(),
                    lr.getSourceClassName(),
                    lr.getSourceMethodName(),
                    lr.getMessage()
                );
            }
        });
        handler.setLevel(Level.INFO);
        mainLogger.addHandler(handler);

        logger = getLogger(Logging.class.getName());
    }

    public static Logger getLogger(String name)
    {
        return Logger.getLogger(name);
    }

    public static void setFormatter(Formatter formatter)
    {
        handler.setFormatter(formatter);
    }

    public static void setLevel(Level level)
    {
        handler.setLevel(level);
        mainLogger.setLevel(level);
    }

    public static void test(String message)
    {
        logger.log(Level.FINEST, message);
        logger.log(Level.FINER, message);
        logger.log(Level.FINE, message);
        logger.log(Level.INFO, message);
        logger.log(Level.WARNING, message);
        logger.log(Level.SEVERE, message);
    }
}
